==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/fi.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "tallennetaan...",
    "saved!" : "tallennettu!",
    "failed!" : "epäonnistui!",
    "Saved" : "Tallennettu",
    "There was a problem saving your changes. Click to resume editing." : "Muutoksien tallentamisessa ilmeni ongelmia. Napsauta palataksesi muokkaamiseen.",
    "An error occurred!" : "Tapahtui virhe!",
    "Edit" : "Muokkaa",
    "Mixed" : "Sekoitettu",
    "Preview" : "Esikatselu",
    "New text file" : "Uusi tekstitiedosto",
    "New text file.txt" : "Uusi tekstitiedosto.txt",
    "You can not open a folder" : "Et voi avata kansiota",
    "This file is too big to be opened. Please download the file instead." : "Tiedosto on liian suuri avattavaksi. Lataa tiedosto, jotta voit avata sen.",
    "Cannot read the file." : "TIedoston lukeminen epäonnistui.",
    "Invalid file path supplied." : "Virheellinen tiedostopolku.",
    "The file is locked." : "Tiedosto on lukittu.",
    "An internal server error occurred." : "Tapahtui palvelimen sisäinen virhe.",
    "You can not write to a folder" : "Et voi kirjoittaa kansioon",
    "Cannot save file as it has been modified since opening" : "Tiedostoa ei voi tallentaa, koska sitä on muokattu avaamisen jälkeen",
    "Insufficient permissions" : "Oikeudet eivät riitä",
    "File path not supplied" : "TIedoston polkua ei annettu",
    "File mtime not supplied" : "Tiedoston mtime-arvoa ei ole annettu",
    "Text editor" : "Tekstimuokkain"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/fi.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "tallennetaan...",
    "saved!" : "tallennettu!",
    "failed!" : "epäonnistui!",
    "Saved" : "Tallennettu",
    "There was a problem saving your changes. Click to resume editing." : "Muutoksien tallentamisessa ilmeni ongelmia. Napsauta palataksesi muokkaamiseen.",
    "An error occurred!" : "Tapahtui virhe!",
    "Edit" : "Muokkaa",
    "Mixed" : "Sekoitettu",
    "Preview" : "Esikatselu",
    "New text file" : "Uusi tekstitiedosto",
    "New text file.txt" : "Uusi tekstitiedosto.txt",
    "You can not open a folder" : "Et voi avata kansiota",
    "This file is too big to be opened. Please download the file instead." : "Tiedosto on liian suuri avattavaksi. Lataa tiedosto, jotta voit avata sen.",
    "Cannot read the file." : "TIedoston lukeminen epäonnistui.",
    "Invalid file path supplied." : "Virheellinen tiedostopolku.",
    "The file is locked." : "Tiedosto on lukittu.",
    "An internal server error occurred." : "Tapahtui palvelimen sisäinen virhe.",
    "You can not write to a folder" : "Et voi kirjoittaa kansioon",
    "Cannot save file as it has been modified since opening" : "Tiedostoa ei voi tallentaa, koska sitä on muokattu avaamisen jälkeen",
    "Could not write to file." : "Tiedostoon ei voitu kirjoittaa.",
    "Insufficient permissions" : "Oikeudet eivät riitä",
    "File path not supplied" : "TIedoston polkua ei annettu",
    "File mtime not supplied" : "Tiedoston mtime-arvoa ei ole annettu",
    "Share not found" : "Jakoa ei löytynyt",
    "You are not authorized to open this share" : "Sinulla ei ole valtuuksia avata tätä jakoa",
    "Text editor" : "Tekstimuokkain"
},
"nplurals=2; plural=(n != 1);");
